@@ -1,9 +1,9 @@
 package Egg::Plugin::YAML;
 #
 # Copyright 2006 Bee Flag, Corp. All Rights Reserved.
-# Masatoshi Mizuno <mizuno@bomcity.com>
+# Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: YAML.pm 185 2007-02-17 07:18:18Z lushe $
+# $Id: YAML.pm 245 2007-02-24 18:21:27Z lushe $
 #
 use strict;
 use warnings;
@@ -75,7 +75,7 @@ L<YAML>,
 
 =head1 AUTHOR
 
-Masatoshi Mizuno, <lt>L<mizunoE<64>bomcity.com><gt>
+Masatoshi Mizuno, E<lt>lusheE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
